/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.chronos.scheduling;

import java.util.Optional;
import com.openexchange.annotation.NonNull;
import com.openexchange.chronos.Attachment;
import com.openexchange.chronos.CalendarUser;
import com.openexchange.exception.OXException;

/**
 * {@link IncomingSchedulingObject}
 *
 * @author <a href="mailto:daniel.becker@open-xchange.com">Daniel Becker</a>
 * @since v7.10.4
 */
public interface IncomingSchedulingObject {

    /**
     * Get the originator of the incoming scheduling message
     *
     * @return The originator
     * @throws OXException in case originator can't be found
     */
    @NonNull
    CalendarUser getOriginator() throws OXException;

    /**
     * Get an attachment for the supplied identifier that was received
     * along the incoming scheduling change
     * 
     * @param attachmentIdentifier The attachment identifier. Can be e.g.
     *            the URL of the attachment in the corresponding mail
     * @return An optional that may contain the parsed attachment
     */
    Optional<Attachment> getAttachment(String attachmentIdentifier);

}
